@@ -235,8 +235,8 @@ class DataTypes:
         return DataTypes.type({
             'type': 'str',
             'message': {
-                lang.EN: "{name} must be an string",
-                lang.ES: "{name} debe ser una cadena de texto",
+                lang.EN: "{name} must be a valid string",
+                lang.ES: "{name} debe ser una cadena de texto válida",
             }
         }, ptyp2)
 
@@ -317,6 +317,10 @@ class DataTypes:
     def mandatory(ptype: dict) -> dict:
         return DataTypes.type(ptype, {'mandatory': True})
 
+    @staticmethod
+    def optional(ptype: dict) -> dict:
+        return DataTypes.type(ptype, {'mandatory': False})
+
     @staticmethod
     def lower(ptype: dict) -> dict:
         return DataTypes.type(ptype, {'to': 'lower'})
