@@ -16,6 +16,11 @@ class Query(DataSchema):
         super(Query, self).__init__(request.args)
 
 
+class InUrl(DataSchema):
+    def __init__(self, data):
+        super(InUrl, self).__init__(data)
+
+
 def flask_json(**kwargs):
     def inner_function(function):
         @functools.wraps(function)
@@ -38,4 +43,22 @@ def flask_query(**kwargs):
             return function(**outdata)
         return wrapper
     return inner_function
-	
\ No newline at end of file
+
+
+def __normalize_escaped_codes(pvalue: str) -> str:
+    pvalue = pvalue.replace('${slash}', '/')
+    pvalue = pvalue.replace('${backslash}', '\\')
+    return pvalue
+
+
+def flask_url(**data_schema):
+    def inner_function(function):
+        @functools.wraps(function)
+        def arg_wrapper(**kwargs2):
+            for key in kwargs2.keys():
+                kwargs2[key] = __normalize_escaped_codes(kwargs2[key])
+            args_validator = InUrl(kwargs2)
+            data = args_validator.validate(data_schema)
+            return function(**data)
+        return arg_wrapper
+    return inner_function
