@@ -93,8 +93,8 @@ VAL_ERROR_PARAM_IS_TOO_SHORT = {
     EN: "{name} is too short (min. {minsize})",
     ES: "{name} es demasiado corto (mín. {minsize})"
 }
-VAL_ERROR_PARAM_IS_TOO_LONG = {
-    EN: "{name} is too long (max. {maxsize})",
+VAL_ERROR_PARAM_IS_TOO_LARGE = {
+    EN: "{name} is too large (max. {maxsize})",
     ES: "{name} es demasiado largo (máx. {maxsize})",
 }
 VAL_ERROR_PARAM_IS_TOO_SMALL = {
@@ -109,6 +109,10 @@ VAL_ERROR_LIST_ITEM_HAS_INVALID_ELEMENT = {
     EN: "{name} has an invalid element. {message}",
     ES: "{name} tiene un elemento no válido. {message}",
 }
+VAL_ERROR_DICT_ITEM_HAS_INVALID_ELEMENT = {
+    EN: "{name} has an invalid field. {message}",
+    ES: "{name} tiene un campo no válido. {message}",
+}
 VAL_ERROR_PARAM_HAS_INVALID_VALUE = {
     EN: "{name} has a not valid value",
     ES: "{name} tiene un valor no válido",
@@ -129,3 +133,7 @@ VAL_ERROR_PARAM_DATETIME_FORMAT = {
     EN: "{name} must be a valid date and time with format {datetime_format}",
     ES: "{name} debe ser una fecha y hora válida con el formato {datetime_format}",
 }
+VAL_ERROR_DICT_ITEM_HAS_NOT_DEFINED_DATA_VALIDATION = {
+    EN: "{name} has not defined a data validation",
+    ES: "{name} no tiene definido una validación del dato",
+}
