@@ -224,6 +224,12 @@ class SchemaValidator:
 
         # -- comprueba el tipo 'int' o 'float'
         if isinstance(value, int) or isinstance(value, float):
+            keyword = KEYWORD_MIN_SIZE
+            min_size = self._get_int(keyword)
+            _check_minsize(label, str(value), min_size)
+            keyword = KEYWORD_MAX_SIZE
+            max_size = self._get_int(keyword)
+            _check_maxsize(label, str(value), max_size)
             keyword = KEYWORD_MIN_VALUE
             min_value = self._get_int(keyword)
             _check_minvalue(label, value, min_value)
@@ -255,6 +261,12 @@ class SchemaValidator:
             item_schema = self._get_dict(keyword)
             _check_item_list_schema(label, value, item_schema)
 
+        # -- comprueba el tipo 'dict'
+        if isinstance(value, dict):
+            keyword = KEYWORD_SCHEMA
+            item_schema = self._get_dict(keyword)
+            _check_item_dict_schema(label, value, item_schema)
+
         # -- aplica las funciones de casting
         keyword = KEYWORD_CAST
         cast = self._get_dict(keyword)
@@ -559,7 +571,7 @@ def _check_minsize(name: str, value: str, minsize: int or None):
 def _check_maxsize(name: str, value: str, maxsize: int or None):
     slen = len(util.trim(value))
     if value is not None and maxsize is not None and slen > maxsize:
-        raise SchemaValidationFailure(lang.VAL_ERROR_PARAM_IS_TOO_LONG, {KEYWORD_NAME: name, 'maxsize': maxsize})
+        raise SchemaValidationFailure(lang.VAL_ERROR_PARAM_IS_TOO_LARGE, {KEYWORD_NAME: name, 'maxsize': maxsize})
 
 
 def _check_minvalue(name: str, value: any, minvalue: any):
@@ -582,6 +594,21 @@ def _check_item_list_schema(name: str, plist: list, item_schema: dict):
                 raise SchemaValidationFailure(lang.VAL_ERROR_LIST_ITEM_HAS_INVALID_ELEMENT, {KEYWORD_NAME: name, 'message': ex.get_message()})
 
 
+def _check_item_dict_schema(name: str, pdict: dict, item_schema: dict):
+    if item_schema is not None:
+        for pitem in pdict.keys():
+            schema = item_schema.get(pitem)
+            if schema is None:
+                raise SchemaValidationFailure(lang.VAL_ERROR_DICT_ITEM_HAS_NOT_DEFINED_DATA_VALIDATION, {KEYWORD_NAME: name})
+        for pkey, schema in item_schema.items():
+            schema_validator = SchemaValidator(schema)
+            pvalue = pdict.get(pkey)
+            try:
+                schema_validator.validate(pkey, pvalue)
+            except SchemaValidationFailure as ex:
+                raise SchemaValidationFailure(lang.VAL_ERROR_DICT_ITEM_HAS_INVALID_ELEMENT, {KEYWORD_NAME: name, 'message': ex.get_message()})
+
+
 def _check_whitelist(name: str, value: any, whitelist: list, icase: bool = True):
     if whitelist is None:
         return
